@@ -21,7 +21,6 @@
 #include "webpage.h"
 #include "browserwindow.h"
 #include "mainapplication.h"
-#include "webtab.h"
 #include "clickablelabel.h"
 #include "closedtabsmanager.h"
 #include "locationbar.h"
@@ -71,9 +70,9 @@ void MenuTabs::mouseReleaseEvent(QMouseEvent* event)
     if (event->button() == Qt::MiddleButton) {
         QAction* action = actionAt(event->pos());
         if (action && action->isEnabled()) {
-            WebTab* tab = qobject_cast<WebTab*>(qvariant_cast<QWidget*>(action->data()));
+            auto* tab = qobject_cast<WebTab*>(qvariant_cast<QWidget*>(action->data()));
             if (tab) {
-                emit closeTab(tab->tabIndex());
+                Q_EMIT closeTab(tab->tabIndex());
                 action->setEnabled(false);
                 event->accept();
             }
@@ -261,7 +260,7 @@ void TabWidget::aboutToShowTabsMenu()
             continue;
         }
 
-        QAction* action = new QAction(this);
+        auto* action = new QAction(this);
         action->setIcon(tab->icon());
 
         if (i == currentIndex()) {
@@ -303,8 +302,8 @@ void TabWidget::aboutToShowClosedTabsMenu()
 
 void TabWidget::actionChangeIndex()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
-        WebTab* tab = qobject_cast<WebTab*>(qvariant_cast<QWidget*>(action->data()));
+    if (auto* action = qobject_cast<QAction*>(sender())) {
+        auto* tab = qobject_cast<WebTab*>(qvariant_cast<QWidget*>(action->data()));
         if (tab) {
             m_tabBar->ensureVisible(tab->tabIndex());
             setCurrentIndex(tab->tabIndex());
@@ -343,7 +342,7 @@ int TabWidget::addView(const LoadRequest &req, const QString &title, const Qz::N
         }
     }
 
-    WebTab* webTab = new WebTab(m_window);
+    auto* webTab = new WebTab(m_window);
     webTab->setPinned(pinned);
     webTab->locationBar()->showUrl(url);
     m_locationBars->addWidget(webTab->locationBar());
@@ -387,8 +386,8 @@ int TabWidget::addView(const LoadRequest &req, const QString &title, const Qz::N
         m_tabBar->ensureVisible(index);
     }
 
-    emit changed();
-    emit tabInserted(index);
+    Q_EMIT changed();
+    Q_EMIT tabInserted(index);
 
     return index;
 }
@@ -419,8 +418,8 @@ int TabWidget::insertView(int index, WebTab *tab, const Qz::NewTabPositionFlags
         m_tabBar->ensureVisible(index);
     }
 
-    emit changed();
-    emit tabInserted(newIndex);
+    Q_EMIT changed();
+    Q_EMIT tabInserted(newIndex);
 
     return newIndex;
 }
@@ -465,8 +464,8 @@ void TabWidget::closeTab(int index)
 
     updateClosedTabsButton();
 
-    emit changed();
-    emit tabRemoved(index);
+    Q_EMIT changed();
+    Q_EMIT tabRemoved(index);
 }
 
 void TabWidget::requestCloseTab(int index)
@@ -519,16 +518,16 @@ void TabWidget::currentTabChanged(int index)
 
     m_window->currentTabChanged();
 
-    emit changed();
+    Q_EMIT changed();
 }
 
 void TabWidget::tabWasMoved(int before, int after)
 {
     m_lastBackgroundTab = nullptr;
 
-    emit changed();
+    Q_EMIT changed();
     if (!m_blockTabMovedSignal) {
-        emit tabMoved(before, after);
+        Q_EMIT tabMoved(before, after);
     }
 }
 
@@ -669,14 +668,14 @@ void TabWidget::moveTab(int from, int to)
     }
     TabStackedWidget::moveTab(tab->tabIndex(), to);
     m_blockTabMovedSignal = false;
-    emit tabMoved(from, to);
+    Q_EMIT tabMoved(from, to);
 }
 
 int TabWidget::pinUnPinTab(int index, const QString &title)
 {
     const int newIndex = TabStackedWidget::pinUnPinTab(index, title);
     if (index != newIndex && !m_blockTabMovedSignal) {
-        emit tabMoved(index, newIndex);
+        Q_EMIT tabMoved(index, newIndex);
     }
     return newIndex;
 }
@@ -699,7 +698,7 @@ void TabWidget::detachTab(WebTab* tab)
     tab->detach();
     tab->setPinned(false);
 
-    emit tabRemoved(index);
+    Q_EMIT tabRemoved(index);
 
     if (count() == 0) {
         m_window->close();
@@ -766,7 +765,7 @@ void TabWidget::restoreClosedTab(QObject* obj)
 
     ClosedTabsManager::Tab tab;
 
-    QAction* action = qobject_cast<QAction*>(obj);
+    auto* action = qobject_cast<QAction*>(obj);
     if (action && action->data().toInt() != 0) {
         tab = m_closedTabsManager->takeTabAt(action->data().toInt());
     }
@@ -861,7 +860,7 @@ bool TabWidget::restoreState(const QVector<WebTab::SavedTab> &tabs, int currentT
         }
     }
 
-    for (const auto p : qAsConst(childTabs)) {
+    for (const auto &p : qAsConst(childTabs)) {
         const auto indices = p.second;
         for (int index : indices) {
             WebTab *t = weTab(index);
